#!/bin/bash

if [ $# != 1 ]; then
  echo "Usage: $0 <proj>"
  exit 1
fi

# This is coupled with the filename in build.ninja.
FLASH=$1.flash

ninja $FLASH || exit 1
exec qemu-system-arm -S -M connex -pflash $FLASH -nographic -serial /dev/null


## This is the command for dumping the binary.
## `-D` - "disassemble all" (`-d` is not enough, since it tries to be
##        smart and only print sections which are likely to be text (but no
##        such section info exists in binary files))
## `-b binary` - Use the `binary` bfd (rather than ELF).
## `-m arm` - Use `arm` machine (this is necessary since flat binary files
##            don't have information about their architecture).
# arm-none-eabi-objdump -D -b binary -m arm sum.bin

## This is the command for dumping just the `.text` section.
# arm-none-eabi-objdump -d -j.text csum.elf

## This is the command for dumping just the section headers (mnemonic:
## (section _h_eaders)
# arm-none-eabi-objdump -h csum.elf

## This is the command for dumping the symbols (mnemonic: symbol _t_able):
# arm-none-eabi-objdump -t csum.elf

## This is the command for seeing what binary formats are available in this
## objdump.
# arm-none-eabi-objdump -i

## Show all relocations
# arm-none-eabi-readelf -r sum-lds.o

## Show symbol information
## `-n` - "numeric sort" - sort by symbol address instead of symbol name
# arm-none-eabi-nm -n sum-lds.elf
